"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProjectTypeAndTargetsFromOptions = exports.getProjectTypeAndTargetsFromFile = void 0;
const devkit_1 = require("@nx/devkit");
const common_1 = require("@nxrocks/common");
const plugin_1 = require("../graph/plugin");
function getProjectTypeAndTargetsFromFile(projectRootFile, pluginOptions) {
    var _a;
    const { root } = (0, common_1.getNameAndRoot)(projectRootFile);
    const platforms = [];
    let template = 'app';
    if ((0, common_1.hasProjectFile)({ root }, 'android'))
        platforms.push('android');
    if ((0, common_1.hasProjectFile)({ root }, 'ios'))
        platforms.push('ios');
    if ((0, common_1.hasProjectFile)({ root }, 'linux'))
        platforms.push('linux');
    if ((0, common_1.hasProjectFile)({ root }, 'macos'))
        platforms.push('macos');
    if ((0, common_1.hasProjectFile)({ root }, 'web'))
        platforms.push('web');
    if ((0, common_1.hasProjectFile)({ root }, 'windows'))
        platforms.push('windows');
    if ((0, common_1.hasProjectFile)({ root }, '.metadata')) {
        const projectMetadata = (0, common_1.getProjectFileContent)({ root }, '.metadata');
        template =
            ((_a = /project_type: (\w)/.exec(projectMetadata)) === null || _a === void 0 ? void 0 : _a[1]) ||
                'app';
    }
    return getProjectTypeAndTargets(root, template, platforms, (0, plugin_1.normalizePluginOptions)(pluginOptions));
}
exports.getProjectTypeAndTargetsFromFile = getProjectTypeAndTargetsFromFile;
function getProjectTypeAndTargetsFromOptions(options) {
    return getProjectTypeAndTargets(options.projectRoot, options.template, options.platforms, (0, plugin_1.normalizePluginOptions)({ useFvm: options.useFvm }));
}
exports.getProjectTypeAndTargetsFromOptions = getProjectTypeAndTargetsFromOptions;
function getProjectTypeAndTargets(projectRoot, template, platforms, pluginOptions) {
    const targets = {};
    const commands = [
        { key: pluginOptions.analyzeTargetName, value: 'analyze' },
        { key: pluginOptions.assembleTargetName, value: 'assemble' },
        { key: pluginOptions.cleanTargetName, value: 'clean' },
        {
            key: pluginOptions.formatTargetName,
            value: `format ${(0, devkit_1.joinPathFragments)(projectRoot, '*')}`,
        },
        { key: pluginOptions.testTargetName, value: 'test' },
        { key: pluginOptions.genL10nTargetName, value: 'gen-l10n' },
    ];
    if (template === 'app') {
        commands.push({ key: pluginOptions.attachTargetName, value: 'attach' }, { key: pluginOptions.driveTargetName, value: 'drive' }, { key: pluginOptions.installTargetName, value: 'install' }, { key: pluginOptions.runTargetName, value: 'run' });
    }
    if ((platforms === null || platforms === void 0 ? void 0 : platforms.indexOf('android')) != -1) {
        commands.push({ key: pluginOptions.buildAarTargetName, value: 'build aar' }, { key: pluginOptions.buildApkTargetName, value: 'build apk' }, { key: pluginOptions.buildAppbundleTargetName, value: 'build appbundle' }, { key: pluginOptions.buildBundleTargetName, value: 'build bundle' });
    }
    if ((platforms === null || platforms === void 0 ? void 0 : platforms.indexOf('ios')) != -1) {
        commands.push({ key: pluginOptions.buildIosTargetName, value: 'build ios' }, {
            key: pluginOptions.buildIosFrameworkTargetName,
            value: 'build ios-framework',
        }, { key: pluginOptions.buildIpaTargetName, value: 'build ipa' });
    }
    for (const command of commands) {
        targets[command.key] = Object.assign({ executor: `nx:run-commands`, options: {
                command: `${command.key === pluginOptions.formatTargetName
                    ? 'dart'
                    : `${pluginOptions.useFvm === true ? 'fvm ' : ''}flutter`} ${command.value}`,
                cwd: projectRoot,
            } }, ([
            pluginOptions.buildAarTargetName,
            pluginOptions.buildApkTargetName,
            pluginOptions.buildAppbundleTargetName,
            pluginOptions.buildBundleTargetName,
            pluginOptions.buildIosTargetName,
            pluginOptions.buildIosFrameworkTargetName,
            pluginOptions.buildIpaTargetName,
        ].includes(command.key)
            ? {
                outputs: [
                    (0, devkit_1.joinPathFragments)('{workspaceRoot}', projectRoot, 'build'),
                ],
            }
            : {}));
    }
    return {
        projectType: template === 'app' ? 'application' : 'library',
        targets,
    };
}
//# sourceMappingURL=plugin-utils.js.map